changeset 835:c00d90bce252

tools: composition RICH_FORMATS constant has been renamed to RICH_SYNTAXES
author souliane <souliane@mailoo.org>
date Wed, 12 Feb 2014 15:19:48 +0100
parents 2d901b7fa861
children 2cc0201b4613
files frontends/src/tools/composition.py
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/frontends/src/tools/composition.py	Fri Feb 07 22:17:06 2014 +0100
+++ b/frontends/src/tools/composition.py	Wed Feb 12 15:19:48 2014 +0100
@@ -38,12 +38,12 @@
     "horizontalrule": {"tip": "Horizontal rule", "icon": "media/icons/dokuwiki/toolbar/16/hr.png"}
     }
 
 # Define here your rich text formats, the key must match the ones used in button.
 # Tupples values must have 3 elements : prefix to the selection or cursor
 # position, sample text to write if the marker is not applied on a selection,
 # suffix to the selection or cursor position.
 # FIXME: must not be hard-coded like this
-RICH_FORMATS = {"markdown": {"bold": ("**", "bold", "**"),
+RICH_SYNTAXES = {"markdown": {"bold": ("**", "bold", "**"),
                         "italic": ("*", "italic", "*"),
                         "code": ("`", "code", "`"),
                         "heading": ("\n# ", "Heading 1", "\n## Heading 2\n"),
@@ -38,12 +38,12 @@
     }
 
-# Define here your rich text formats, the key must match the ones used in button.
+# Define here your rich text syntaxes, the key must match the ones used in button.
 # Tupples values must have 3 elements : prefix to the selection or cursor
 # position, sample text to write if the marker is not applied on a selection,